==> ToolChain_STM32_1.0.38.tar.bz: ToolChain_STM32_1.0.38/ToolChain/install_03_OpenOCD.sh <==
#!/bin/bash

#
#  Install script for Open On-Chip Debugger tool made by Dominic Rath.
#  Script written by Gregor Rebel 2010-2011.
#  OpenOCD - On Chip Debugger
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition x86
# KUbuntu 11.04 x86
# openSuSE 11.4 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="999_open_ocd"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

InstallInHomeDir="1"
if [ "$InstallInHomeDir" == "1" ]; then
  Prefix=`pwd`  # install into subfolder of ToolChain/ for current user only
else
  findPrefix    # install for all users
fi

InstallDir=`pwd`

if [ ! -e OK.Install ]; then #{

echo "installing in $INSTALLPATH ..."

if [ ! -e OK.Packages ]; then #{
  installPackage texlive
  touch OK.Packages
fi #}


#DirName="openocd-0.4.0"
DirName="openocd-0.5.0"
getFile http://download.berlios.de/openocd/ ${DirName}.tar.bz2

OldDir=`pwd`
cd ../../Documentation
mkdir OpenOCD
cd OpenOCD/
wget -rnp -nd -nc http://openocd.berlios.de/doc/html/index.html
cd "$OldDir"

untgj ${DirName} ${DirName}.tar.bz2
add2CleanUp ../cleanup.sh "rm -Rf $INSTALLPATH/$DirName"

if [ ! -d ${DirName} ]; then
  echo "ERROR: Cannot download file (folder ${DirName} not found in `pwd`)!"
  exit 5
fi
cd "${DirName}/"
  echo "compiling $DirName ----------------------------------------------"
  echo "clean..." && make clean >clean.log 2>&1

  #./configure  --prefix=$Prefix --enable-usbprog --enable-ioutil --enable-oocd_trace --enable-jlink --enable-ft2232_ftd2xx && make -j2 && sudo make install && touch Install_OK
  IncludeDir="`pwd`/../../999_libftdi/"
  OK=""
  echo "configure >configure.log..." && ./configure --prefix=$Prefix \
                                                    --enable-ioutil --enable-oocd_trace --enable-jlink \
                                                    --enable-ft2232_libftdi \
                                                    >configure.log 2>&1  && OK="1"
  if [ "$OK" == "" ]; then
    echo "Error during configuring ${DirName}!"
    exit 10
  fi
  for Makefile in $( find ./ -name Makefile ); do
    echo "replacing Werror in $Makefile .."
    replaceInFile $Makefile "-Werror" " "
  done
  if [ "$AmountCPUs" == "" ]; then
    AmountCPUs="1"
  fi
  AmountJobs=$(( $AmountCPUs * 2 ))
  echo "make      >make.log..."      && make -j$AmountJobs >make.log 2>&1 && \
  echo "pdf       >pdf.log..."       && make pdf -j$AmountJobs >pdf.log 2>&1 ; \
  echo "install   >install.log..."   && sudo make install >install.log 2>&1 && \
  touch Install_OK

  if [ ! -e Install_OK ]; then #{
    echo "Error during compiling ${DirName}!"
    echo "Check log files:"
    find `pwd`/ -name "*.log" -exec echo "  less {}" \;
    find `pwd`/ -name "*.err" -exec echo "  less {}" \;
    exit 10
  fi #}

cd ..
#? Chowning openocd creates problems in using it later..
#? sudo chown -R $USER: .

if [ -e "$Prefix/bin/openocd" ]; then
    IsInstalled=`$Prefix/bin/openocd --version  2>&1 | grep Debugger`
    if [ "$IsInstalled" != "" ]; then
      sudo chmod 4755 $Prefix/bin/openocd
      echo "Installed version: $IsInstalled"
      addLine ../../cleanup.sh "rm -Rf `pwd`/${DirName}/"
      cd "$InstallDir"
      
      echo "" >OK.Install
    fi
fi
fi #} [ ! -e OK.Install ]; then
if [ ! -e OK.Docs ]; then #{
  #getFile http://download.berlios.de/openocd/ openocd.pdf "OpenOCD_Manual.pdf" ../../Documentation/OpenOCD/
  getFile http://openocd.sourceforge.net/doc/pdf/ openocd.pdf "OpenOCD_UsersGuide.pdf" ../../Documentation/OpenOCD/
  if [ -e ../../Documentation/OpenOCD/OpenOCD_UsersGuide.pdf ]; then
    touch OK.Docs
  fi
fi
if [  -e OK.Install ]; then #{

  if [ ! -e ../scripts/interface.cfg_ ]; then #{
    ConfigFolder="$InstallDir/share/openocd/scripts/interface/"
    OldDir=`pwd`
    cat <<END_OF_CFG >../scripts/interface.cfg
#!/bin/bash
#
# (c) Gregor Rebel 2010-2011
#

# Choose config file that suits to your program adapter
#
# Configfiles are read from folder
# $ConfigFolder

# remove leading # from desired interface to use: 
Interface="olimex-arm-usb-tiny-h.cfg"
END_OF_CFG

  cd "$ConfigFolder"
  Interfaces=`ls *.cfg`
  cd "$OldDir"

  for Interface in $Interfaces; do
    echo "# Interface=\"$Interface\"" >>../scripts/interface.cfg
  done
  fi #}
  if [ "$InstallInHomeDir" == "1" ]; then
    createLink ../$INSTALLPATH/bin/openocd ../bin/openocd
    addLine ../scripts/createLinks.sh "rm 2>/dev/null $INSTALLPATH;  ln -sv \$Source/ToolChain_STM32/ToolChain/$INSTALLPATH/share/openocd/scripts/  $INSTALLPATH"

    #X addLine ../scripts/SourceMe.sh "export PATH=\"\$HOME/Source/ToolChain_STM32/ToolChain/$INSTALLPATH/bin/:\$PATH\" #$0"
  else
    createLink $Prefix/bin/openocd ../bin/openocd
    #X addLine ../scripts/SourceMe.sh "export PATH=\"$Prefix/bin/:\$PATH\" #$0"
  fi
  echo "Installed successfully: $INSTALLPATH"
#}
else
  echo "failed to install $INSTALLPATH"
  exit 10
fi

cd ..
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0

==> ToolChain_STM32_1.0.42.tar.bz: ToolChain_STM32_1.0.42/ToolChain/install_03_OpenOCD.sh <==
#!/bin/bash

#{  Install script for Open On-Chip Debugger tool made by Dominic Rath.
#  Script written by Gregor Rebel 2010-2011.
#  OpenOCD - On Chip Debugger
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition x86
# KUbuntu 11.04 x86
# openSuSE 11.4 x86
# XUbuntu 11.10 x64
# openSuSE 12.1 x86
#}

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="999_open_ocd"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

InstallInHomeDir="1"
if [ "$InstallInHomeDir" == "1" ]; then
  Prefix=`pwd`  # install into subfolder of ToolChain/ for current user only
else
  findPrefix    # install for all users
fi

InstallDir=`pwd`

if [ ! -e OK.Documentation ]; then #{
  Error=""
  dir ../../Documentation/OpenOCD
  OldDir=`pwd`
  cd ../../Documentation/OpenOCD
  wget -rnp -nd -nc http://openocd.berlios.de/doc/html/index.html
  cd "$OldDir"

  if [ "$Error" == "" ]; then
    echo "Documentation complete: $INSTALLPATH."
    touch OK.Documentation
  fi
fi #}
if [ ! -e OK.Install ]; then #{

echo "installing in $INSTALLPATH ..."

if [ ! -e OK.Packages ]; then #{
  installPackage texlive
  touch OK.Packages
fi #}


#DirName="openocd-0.4.0"
DirName="openocd-0.5.0"
getFile http://download.berlios.de/openocd/ ${DirName}.tar.bz2

untgj ${DirName} ${DirName}.tar.bz2
#add2CleanUp ../cleanup.sh "rm -Rf $INSTALLPATH/$DirName"

if [ ! -d ${DirName} ]; then
  echo "ERROR: Cannot download file (folder ${DirName} not found in `pwd`)!"
  exit 5
fi
cd "${DirName}/"
  echo "compiling $DirName ----------------------------------------------"
  echo "clean..." && make clean >clean.log 2>&1

  #./configure  --prefix=$Prefix --enable-usbprog --enable-ioutil --enable-oocd_trace --enable-jlink --enable-ft2232_ftd2xx && make -j2 && sudo make install && touch Install_OK
  IncludeDir="`pwd`/../../999_libftdi/"
  OK=""
  echo "configure >configure.log..." && ./configure --prefix=$Prefix \
                                                    --enable-ioutil --enable-oocd_trace --enable-jlink \
                                                    --enable-ft2232_ftd2xx \
                                                    >configure.log 2>&1  && OK="1"
#                                                    --enable-ft2232_libftdi \

  if [ "$OK" == "" ]; then
    echo "Error during configuring ${DirName}!"
    exit 10
  fi
  for Makefile in $( find ./ -name Makefile ); do
    echo "replacing Werror in $Makefile .."
    replaceInFile $Makefile "-Werror" " "
  done
  if [ "$AmountCPUs" == "" ]; then
    AmountCPUs="1"
  fi
  AmountJobs=$(( $AmountCPUs * 2 ))
  echo "make -j${AmountJobs}  >make.log..."      && make -j$AmountJobs >make.log 2>&1 && \
  echo "pdf       >pdf.log..."       && make pdf -j$AmountJobs >pdf.log 2>&1 ; \
  echo "install   >install.log..."   && sudo make install >install.log 2>&1 && \
  touch Install_OK
  


  if [ ! -e Install_OK ]; then #{
    echo "Error during compiling ${DirName}!"
    echo "Check log files:"
    find `pwd`/ -name "*.log" -exec echo "  less {}" \;
    find `pwd`/ -name "*.err" -exec echo "  less {}" \;
    exit 10
  fi #}

cd ..
#? Chowning openocd creates problems in using it later..
#? sudo chown -R $USER: .

if [ -e "$Prefix/bin/openocd" ]; then
    IsInstalled=`$Prefix/bin/openocd --version  2>&1 | grep Debugger`
    if [ "$IsInstalled" != "" ]; then
      sudo chmod 4755 $Prefix/bin/openocd
      echo "Installed version: $IsInstalled"
      addLine ../../cleanup.sh "rm -Rf `pwd`/${DirName}/"
      cd "$InstallDir"
      
      echo "" >OK.Install
    fi
fi
fi #} [ ! -e OK.Install ]; then
if [ ! -e OK.Docs ]; then #{
  #getFile http://download.berlios.de/openocd/ openocd.pdf "OpenOCD_Manual.pdf" ../../Documentation/OpenOCD/
  getFile http://openocd.sourceforge.net/doc/pdf/ openocd.pdf "OpenOCD_UsersGuide.pdf" ../../Documentation/OpenOCD/
  if [ -e ../../Documentation/OpenOCD/OpenOCD_UsersGuide.pdf ]; then
    touch OK.Docs
  fi
fi #}Docs
if [   -e OK.Install ]; then #{

  if [ ! -e ../scripts/interface.cfg_ ]; then #{
    ConfigFolder="$InstallDir/share/openocd/scripts/interface/"
    OldDir=`pwd`
    cat <<END_OF_CFG >../scripts/interface.cfg
#!/bin/bash
#
# (c) Gregor Rebel 2010-2011
#

# Choose config file that suits to your program adapter
#
# Configfiles are read from folder
# $ConfigFolder

# remove leading # from desired interface to use: 
Interface="olimex-arm-usb-tiny-h.cfg"
END_OF_CFG

  cd "$ConfigFolder"
    
  sudo chown $USER: .
  # ensure that current folder is writable
  cat <<END_OF_CFG >wsn3_oocdlink-h.cfg
#
# Joern Kaipf's OOCDLink
# Modified by Gregor Rebel for Wireless Sensor Node v3 Programming Adapter
#
# http://www.joernonline.de/contrexx2/cms/index.php?page=126
#

interface ft2232
ft2232_device_desc "WSN3 OOCDLink-H A"
ft2232_layout oocdlink
ft2232_vid_pid 0x0403 0xbafa
adapter_khz 5
reset_config trst_and_srst separate trst_push_pull srst_push_pull

END_OF_CFG

  Interfaces=`ls *.cfg`
  cd "$OldDir"

  for Interface in $Interfaces; do
    echo "# Interface=\"$Interface\"" >>../scripts/interface.cfg
  done
  fi #}
  if [ "$InstallInHomeDir" == "1" ]; then
    createLink ../$INSTALLPATH/bin/openocd ../bin/openocd
    addLine ../scripts/createLinks.sh "2>/dev/null $INSTALLPATH;  ln -sv \$Source/ToolChain_STM32/ToolChain/$INSTALLPATH/share/openocd/scripts/  $INSTALLPATH"

    #X addLine ../scripts/SourceMe.sh "export PATH=\"\$HOME/Source/ToolChain_STM32/ToolChain/$INSTALLPATH/bin/:\$PATH\" #$0"
  else
    createLink $Prefix/bin/openocd ../bin/openocd
    #X addLine ../scripts/SourceMe.sh "export PATH=\"$Prefix/bin/:\$PATH\" #$0"
  fi
  echo "Installed successfully: $INSTALLPATH"
#}
else
  echo "failed to install $INSTALLPATH"
  exit 10
fi

cd ..

#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0
